@@ -49,7 +49,7 @@ class NoteOff(MIDIMessage):
     """
 
     _STATUS = 0x80
-    _STATUSMASK = 0xf0
+    _STATUSMASK = 0xF0
     LENGTH = 3
 
     def __init__(self, note, velocity=0, *, channel=None):
@@ -60,12 +60,13 @@ class NoteOff(MIDIMessage):
             raise self._EX_VALUEERROR_OOR
 
     def __bytes__(self):
-        return bytes([self._STATUS | (self.channel & self.CHANNELMASK),
-                      self.note, self.velocity])
+        return bytes(
+            [self._STATUS | (self.channel & self.CHANNELMASK), self.note, self.velocity]
+        )
 
     @classmethod
     def from_bytes(cls, msg_bytes):
-        return cls(msg_bytes[1], msg_bytes[2],
-                   channel=msg_bytes[0] & cls.CHANNELMASK)
+        return cls(msg_bytes[1], msg_bytes[2], channel=msg_bytes[0] & cls.CHANNELMASK)
+
 
 NoteOff.register_message_type()
